<?php
// This file is part of Moodle - https://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <https://www.gnu.org/licenses/>.

namespace tiny_copysafepdfeditor;

use context;
use editor_tiny\plugin;
use editor_tiny\plugin_with_buttons;
use editor_tiny\plugin_with_configuration;

/**
 * Tiny Copy Safe PDF editor plugin for Moodle.
 *
 * @package     tiny_copysafepdfeditor
 * @copyright   2025 DeveloperCK <developerck@gmail.com>
 * @license     https://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
class plugininfo extends plugin implements plugin_with_configuration, plugin_with_buttons {

    /**
     * Get a list of the buttons provided by this plugin.
     *
     * @return array
     */
    public static function get_available_buttons(): array {
        return [
            'tiny_copysafepdfeditor/plugin',
        ];
    }

    /**
     * Allows to pass to pass options from the PHP to the JavaScript API of the plugin.
     *
     * @param context $context
     * @param array $options
     * @param array $fpoptions
     * @param ?\editor_tiny\editor $editor = null
     * @return array
     */
    public static function get_plugin_configuration_for_context(
        context $context,
        array $options,
        array $fpoptions,
        ?\editor_tiny\editor $editor = null
    ): array {
        global $CFG;
        return [
            // Your values go here.
            // These will be mapped to a namespaced EditorOption in Tiny.
            'wwwroot' => $CFG->wwwroot
        ];
    }
}
